DexEncodedFieldRef class

A resolved field reference (as an encoded value in annotations or static initializers).

Inheritance
Annotations
  • @immutable

Constructors

DexEncodedFieldRef(DexFieldId field)
Creates a field reference encoded value.
const

Properties

field DexFieldId
The resolved field identifier.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override