DexEncodedMethodHandle class

A method handle reference. These are not fully resolved because the method_handle pool is not parsed.

Inheritance
Annotations
  • @immutable

Constructors

DexEncodedMethodHandle(int index)
Creates a method handle encoded value.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
index int
The raw method handle index.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override