DexEncodedEnum class
A resolved enum constant reference (stored as a field reference in the DEX format).
- Inheritance
-
- Object
- DexEncodedValue
- DexEncodedEnum
- Annotations
-
- @immutable
Constructors
- DexEncodedEnum(DexFieldId field)
-
Creates an enum encoded value.
const
Properties
- field → DexFieldId
-
The resolved field identifier of the enum constant.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override