DexEncodedPrimitive class
A primitive numeric value (byte, short, char, int, long, float, or double) stored as its raw integer representation.
- Inheritance
-
- Object
- DexEncodedValue
- DexEncodedPrimitive
- Annotations
-
- @immutable
Constructors
- DexEncodedPrimitive({required int typeTag, required int value})
-
Creates a primitive encoded value.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeTag → int
-
The DEX value_type tag (0x00=byte, 0x02=short, 0x03=char,
0x04=int, 0x06=long, 0x10=float, 0x11=double).
final
- value → int
-
The raw integer representation of the value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override